@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 use base 'Chart::Clicker::Decoration::Base';
-__PACKAGE__->mk_accessors(qw(above color stroke value));
+__PACKAGE__->mk_accessors(qw(color stroke value));
 
 use Chart::Clicker::Drawing::Color;
 use Chart::Clicker::Drawing::Stroke;
@@ -12,9 +12,6 @@ sub new {
     my $proto = shift();
     my $self = $proto->SUPER::new(@_);
 
-    unless(defined($self->above())) {
-        $self->above(0);
-    }
     unless(defined($self->color())) {
         $self->color(
             new Chart::Clicker::Drawing::Color({
@@ -68,11 +65,6 @@ Used to highlight a particular value.
 
 =over 4
 
-=item above
-
-Set/Get the 'above' flag that determines if a marker is drawn above or below
-the rendered values.
-
 =item color
 
 Set/Get the color for this marker.
