@@ -1,5 +1,6 @@
 package Chart::Clicker::Drawing::Color;
 use strict;
+use warnings;
 
 use base 'Class::Accessor';
 __PACKAGE__->mk_accessors(qw(red green blue alpha name));
@@ -20,9 +21,66 @@ my %colors = (
     'silver'    => [ .75, .75, .75,  1 ],
     'teal'      => [   0, .31, .31,  1 ],
     'white'     => [   1,   1,   1,  1 ],
-    'yellow'    => [   1,   1,   0,  1 ]
+    'yellow'    => [   1,   1,   0,  1 ],
 );
 
+sub new {
+    my $proto = shift();
+    my $self = $proto->SUPER::new(@_);
+
+    unless(defined($self->red())) {
+        if($self->name()) {
+            if(exists($colors{lc($self->name())})) {
+                $self->red($colors{lc($self->name())}->[0]);
+                $self->green($colors{lc($self->name())}->[1]);
+                $self->blue($colors{lc($self->name())}->[2]);
+                $self->alpha($colors{lc($self->name())}->[3]);
+            }
+        }
+    }
+
+    return $self;
+}
+
+sub as_string {
+    my $self = shift();
+
+    return sprintf('%0.2f,%0.2f,%0.2f,%0.2f',
+        $self->red(), $self->green(),
+        $self->blue(), $self->alpha()
+    );
+}
+
+sub clone {
+    my $self = shift();
+
+    return new Chart::Clicker::Drawing::Color({
+        red => $self->red(), green => $self->green(),
+        blue => $self->blue(), alpha => $self->alpha()
+    });
+}
+
+sub rgb {
+    my $self = shift();
+
+    return ($self->red(), $self->green(), $self->blue());
+}
+
+sub rgba {
+    my $self = shift();
+
+    return ($self->red(), $self->green(), $self->blue(), $self->alpha());
+}
+
+sub names {
+    my $self = shift();
+
+    return keys(%colors);
+}
+
+1;
+__END__
+
 =head1 NAME
 
 Chart::Clicker::Drawing::Color
@@ -60,25 +118,6 @@ white and yellow.  Any case is fine, navy, NAVY or Navy.
 
 Creates a new Chart::Clicker::Drawing::Color.
 
-=cut
-sub new {
-    my $proto = shift();
-    my $self = $proto->SUPER::new(@_);
-
-    unless(defined($self->red())) {
-        if($self->name()) {
-            if(exists($colors{lc($self->name())})) {
-                $self->red($colors{lc($self->name())}->[0]);
-                $self->green($colors{lc($self->name())}->[1]);
-                $self->blue($colors{lc($self->name())}->[2]);
-                $self->alpha($colors{lc($self->name())}->[3]);
-            }
-        }
-    }
-
-    return $self;
-}
-
 =back
 
 =head2 Class Methods
@@ -109,52 +148,18 @@ Get the name of this color.  Only valid if the color was created by name.
 
 Get a string version of this Color in the form of RED, GREEN, BLUE, ALPHA
 
-=cut
-sub as_string {
-    my $self = shift();
-
-    sprintf('%0.2f,%0.2f,%0.2f,%0.2f',
-        $self->red(), $self->green(),
-        $self->blue(), $self->alpha()
-    );
-}
-
 =item clone
 
 Clone this color
 
-=cut
-sub clone {
-    my $self = shift();
-
-    return new Chart::Clicker::Drawing::Color({
-        red => $self->red(), green => $self->green(),
-        blue => $self->blue(), alpha => $self->alpha()
-    });
-}
-
 =item rgb
 
 Get the RGB values as an array
 
-=cut
-sub rgb {
-    my $self = shift();
-
-    return ($self->red(), $self->green(), $self->blue());
-}
-
 =item rgba
 
 Get the RGBA values as an array
 
-=cut
-sub rgba {
-    my $self = shift();
-
-    return ($self->red(), $self->green(), $self->blue(), $self->alpha());
-}
-
 =back
 
 =head2 Static Methods
@@ -165,13 +170,6 @@ sub rgba {
 
 Gets the list of predefined color names.
 
-=cut
-sub names {
-    my $self = shift();
-
-    return keys(%colors);
-}
-
 =back
 
 =head1 AUTHOR
@@ -182,5 +180,7 @@ Cory 'G' Watson <gphat@cpan.org>
 
 perl(1)
 
-=cut
-1;
+=head1 LICENSE
+
+You can redistribute and/or modify this code under the same terms as Perl
+itself.
